Generates subgroup membership pairs (Z1, Z2) for a multi-view data set with
n observations and two views.
Usage
mv_memberships_gen(n, Pi)
Arguments
n
number of observations
Pi
K1 x K2 matrix where the (k, k')th entry contains the probability of an observation
belonging to subgroup k in View 1 and subgroup k' in View 2
Value
n x 2 matrix where the first column contains subgroup memberships for View 1 (Z1)
and the second column contains subgroup memberships for View 2 (Z2).
References
Gao, L.L., Bien, J., Witten, D. (2019) Are Clusterings of Multiple Data Views Independent?
to appear in Biostatistics, <DOI:10.1093/biostatistics/kxz001>
Gao, L.L., Witten, D., Bien, J. Testing for Association in Multi-View Network Data, preprint.